Author: djg
Date: Mon Sep 24 16:09:53 2007
New Revision: 42274

URL: http://llvm.org/viewvc/llvm-project?rev=42274&view=rev
Log:
Merge hasDotLoc and hasDotFile into hasDotLocAndDotFile since .loc and .file
aren't really usable without each other. 

Modified:
    llvm/trunk/include/llvm/Target/TargetAsmInfo.h
    llvm/trunk/lib/Target/TargetAsmInfo.cpp

Modified: llvm/trunk/include/llvm/Target/TargetAsmInfo.h
URL: 
http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/Target/TargetAsmInfo.h?rev=42274&r1=42273&r2=42274&view=diff

==============================================================================
--- llvm/trunk/lib/Target/TargetAsmInfo.cpp (original)
+++ llvm/trunk/lib/Target/TargetAsmInfo.cpp Mon Sep 24 16:09:53 2007
@@ -81,8 +81,7 @@
   AbsoluteDebugSectionOffsets(false),
   AbsoluteEHSectionOffsets(false),
   HasLEB128(false),
-  HasDotLoc(false),
-  HasDotFile(false),
+  HasDotLocAndDotFile(false),
   SupportsDebugInformation(false),
   SupportsExceptionHandling(false),
   DwarfRequiresFrameSection(true),


_______________________________________________
llvm-commits mailing list
llvm-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-commits

Reply via email to
--- llvm/trunk/include/llvm/Target/TargetAsmInfo.h (original)
+++ llvm/trunk/include/llvm/Target/TargetAsmInfo.h Mon Sep 24 16:09:53 2007
@@ -286,14 +286,11 @@
     ///
     bool HasLEB128; // Defaults to false.
     
     /// hasDotLoc - True if target asm supports .loc directives.
     ///
-    bool HasDotLoc; // Defaults to false.
+    bool HasDotLocAndDotFile; // Defaults to false.
     
-    /// HasDotFile - True if target asm supports .file directives.
-    ///
-    bool HasDotFile; // Defaults to false.
-
     /// SupportsDebugInformation - True if target supports emission of 
debugging
     /// information.
     bool SupportsDebugInformation;
@@ -568,11 +565,8 @@
     bool hasLEB128() const {
       return HasLEB128;
     }
-    bool hasDotLoc() const {
-      return HasDotLoc;
-    }
-    bool hasDotFile() const {
-      return HasDotFile;
+    bool hasDotLocAndDotFile() const {
+      return HasDotLocAndDotFile;
     }
     bool doesSupportDebugInformation() const {
       return SupportsDebugInformation;
@@ -286,14 +286,11 @@
     bool HasLEB128; // Defaults to false.
     
-    /// hasDotLoc - True if target asm supports .loc directives.
+    /// hasDotLocAndDotFile - True if target asm supports .loc and .file
+    /// directives for emitting debugging information.
     ///

Modified: llvm/trunk/lib/Target/TargetAsmInfo.cpp
URL: 
http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/Target/TargetAsmInfo.cpp?rev=42274&r1=42273&r2=42274&view=diff

==============================================================================